@@ -1,6 +1,7 @@
 import sys, os
-import difflib
 import argparse
+import difflib, re
+from datetime import datetime
 from . import mail_shell as msl
 
 
@@ -10,15 +11,16 @@ USAGE = "msl [COMMAND] [OPTIONS]. See 'msl --help'."
 
 def main():
 
-	def txt_file(f=None):
+	def file_extention(tp, f=None):
 		ext = os.path.splitext(f)[1]	
-		if ext == '.txt': return f
-		PARSER.error(f"'{f}' is not (.txt) file!")
+		if ext == tp: return f
+		PARSER.error(f"'{f}' is not ({tp}) file!")
 
-	def html_file(f=None):
-		ext = os.path.splitext(f)[1]	
-		if ext == '.html': return f
-		PARSER.error(f"'{f}' is not an html file!")
+	def valid_date(date=None):
+		try: date = datetime.strptime(date, '%d-%m-%Y')
+		except ValueError: 
+			PARSER.error("Invalid date: expected DD-MM-YYYY")
+		return date.strftime("%d-%b-%Y")
 
 	def command_check():
 		if len(sys.argv) == 1: return
@@ -37,10 +39,10 @@ def main():
 		['-s', '--subject' , "select the email which has <Subject>"        ],
 		['-f', '--sender'  , "select emails that are from <sender>"        ],
 		['-T', '--to'      , "select emails that were sent to <reciever>"  ],
-		['-d', '--date'    , "select email that are on ' day-month-year '" ],
+		['-d', '--date'    , "select email that are on DD-MM-YYYY"         ],
 		['-t', '--text'    , "select email that has <TEXT>"                ]]
 
-    # get the arguments and commands
+    # get the arguments and options
 	PARSER = argparse.ArgumentParser(prog="mailshell", description=DESCRIPTION, epilog=EPILOG, usage=USAGE)
 	command_check()
 	PARSER.add_argument('--version', action="store_true", help="see your current version.")
@@ -48,15 +50,18 @@ def main():
 	SUBPARSER = PARSER.add_subparsers(dest="command")
 	SUBPARSER.required = False
 
-	CONTENT_PARSER = SUBPARSER.add_parser('content', help="see the current message content with the included files.")
-	CONTENT_PARSER.add_argument('-f', '--files', action="store_true", help="See the files that are included in the email.")
-	CONTENT_PARSER.add_argument('-i', '--images', action="store_true", help="See the included images.")
+	SUBPARSER.add_parser('login', help="log in to your gmail using email address and the app password.")
+	SUBPARSER.add_parser('cred', help="print your current email address and app password.")
+	SUBPARSER.add_parser('new', help="create new email message.")
+	SUBPARSER.add_parser('subject', help="set a new subject to the message.")
+	SUBPARSER.add_parser('from', help="set a new sender name.")
+
 
 	SET_PARSER = SUBPARSER.add_parser('set', help="add a text manually or from .txt file to you current message.")
-	SET_PARSER.add_argument('-f', '--file', type=txt_file, help="text file path (except .txt files)")
+	SET_PARSER.add_argument('-f', '--file', type=lambda f: file_extention('.txt', f), help="text file path (except .txt files)")
 	
 	HTML_PARSER = SUBPARSER.add_parser('html', help="add html message manually or from html file.")
-	HTML_PARSER.add_argument('-f', '--file', type=html_file, help="html file path (.html)")
+	HTML_PARSER.add_argument('-f', '--file', type=lambda f: file_extention('.html', f), help="html file path (.html)")
 
 	ADD_PARSER = SUBPARSER.add_parser('add', help="add a file or image to your message.")
 	ADD_PARSER.add_argument('file', help="file or image")
@@ -65,17 +70,26 @@ def main():
 	RM_PARSER.add_argument('file', nargs='?', help="the filename that has been included in the message.")
 	RM_PARSER.add_argument('-a', '--all', action="store_true", help="remove all the files in the message attachments.")
 
+	CONTENT_PARSER = SUBPARSER.add_parser('content', help="see the current message content with the included files.")
+	CONTENT_PARSER.add_argument('-f', '--files', action="store_true", help="See the files that are included in the email.")
+	CONTENT_PARSER.add_argument('-i', '--images', action="store_true", help="See the included images.")
+
+	SUBPARSER.add_parser('to', help="set your contact that you will send to.")
+
 	SEND_PARSER = SUBPARSER.add_parser('send', help="send the current message.")
 	SEND_PARSER.add_argument('-T', '--to', help="send the email to [EMAIL ADDRESS]")
 
 	CHECK_PARSER = SUBPARSER.add_parser('check', help="check your emails with a specified mailbox and search command.")
 	CHECK_PARSER.add_argument('-b', '--box', nargs='?', default="Inbox", help="select the mailbox that you want to check (the default: %(default)s).")
 	CHECK_PARSER.add_argument('-l', '--list', action="store_true", help="See the search results as a list.")
+	CHECK_PARSER.add_argument('-d', '--date', type=valid_date, help=SELECTORS[-2][-1])
 
 	DELETE_PARSER = SUBPARSER.add_parser('delete', help="delete emails from mailbox in your account.")
 	DELETE_PARSER.add_argument('-b', '--box', default="Inbox", help="select the mailbox where you want to delete (the default: %(default)s).")
+	DELETE_PARSER.add_argument('-d', '--date', type=valid_date, help=SELECTORS[-2][-1])
 
 	for so, lo, h in SELECTORS:
+		if so == '-d': continue
 		if so in ['-a', '-n']:
 			CHECK_PARSER.add_argument(so, lo, action="store_true", help=h)
 			DELETE_PARSER.add_argument(so, lo, action="store_true", help=h)
@@ -83,14 +97,8 @@ def main():
 			CHECK_PARSER.add_argument(so, lo, help=h)
 			DELETE_PARSER.add_argument(so, lo, help=h)
 
-	SUBPARSER.add_parser('login', help="log in to your gmail using email address and the app password.")
-	SUBPARSER.add_parser('cred', help="print your current email address and app password.")
-	SUBPARSER.add_parser('new', help="create new email message.")
-	SUBPARSER.add_parser('subject', help="set a new subject to the message.")
-	SUBPARSER.add_parser('from', help="set a new sender name.")
-	SUBPARSER.add_parser('to', help="set your contact that you will send to.")
 	SUBPARSER.add_parser('logout', help="log out from your gmail.")
-	SUBPARSER.add_parser('help', help="mailshell helper.")
+	SUBPARSER.add_parser('help', help="the mailshell helper.")
 
 	ARGS = PARSER.parse_args()
 
