@@ -4,6 +4,7 @@ import smtplib, socket
 import json, re, imghdr
 from pathlib import Path
 from os.path import exists
+from pwinput import pwinput
 from os.path import basename
 from getpass import getuser
 from subprocess import call
@@ -12,7 +13,6 @@ from . import email_checker as mc
 from email.message import EmailMessage
 from tempfile import NamedTemporaryFile
 
-
 PORT = 465
 SMTP_SERVER = "smtp.gmail.com"
 USER_DATA = (Path(__file__).parent / "msl-user.json")
@@ -66,6 +66,7 @@ def html_message(mode, filename=None):
 		return
 
 	call(['nano', HTML_FILE])
+	if not exists(HTML_FILE): return
 	with open(HTML_FILE, 'r') as html:
 		if not html.read().strip(): os.remove(HTML_FILE)
 
@@ -85,7 +86,7 @@ def validate_email(address):
 		return True
 	return False
 
-def helpme():
+def helpme(args=None):
 	call(['msl', '--help'])
 
 def show(text=''):
@@ -105,12 +106,13 @@ class User(object):
 		self.address = address
 		self.app_password = password
 
+	def __bool__(self):
+		return bool(self.address)
+
 	def get_user(self):
 		cred = user_data('GET')["credentials"].values()
 		self.address, self.app_password = cred
 
-	def __bool__(self):
-		return bool(self.address)
 
 class Mailshell():
 	def __init__(self):
@@ -133,6 +135,10 @@ class Mailshell():
 			"logout": self.log_out
 		}
 
+	def __getitem__(self, args):
+		connect_to_data()
+		self.commands[args.command](args)
+
 	def __error_login_first(self):
 		print("\nLogin first: type 'msl login' to start create and send your massages.\n")
 
@@ -175,7 +181,7 @@ class Mailshell():
 	def log_in(self, args=None):
 		print('\nLog in:')
 		address = input("> Email address: ").strip()
-		password = input("> App password: ").strip()
+		password = pwinput("> App password: ", mask='*').strip()
 		try:
 			if validate_email(address):
 				try:
@@ -300,6 +306,9 @@ class Mailshell():
 		if not self.__has_message(): return
 		data = user_data('GET')
 		if args.all:
+			if not data["message"]["attachments"]:
+				print("You have no attachments in your message!")
+				return
 			data["message"]["attachments"] = []
 			user_data('POST', data)
 			print("all files are removed from the message.")
@@ -412,9 +421,6 @@ class Mailshell():
 			print(update_warning())
 		except socket.gaierror:
 			self.__error_connection()
-	def __getitem__(self, args):
-		connect_to_data()
-		self.commands[args.command](args)
 		
 
 
